@@ -1,4 +1,5 @@
 {-# LANGUAGE
+    CPP,
     DataKinds,
     PolyKinds,
     TypeFamilies,
@@ -6,6 +7,10 @@
     TypeOperators,
     UndecidableInstances #-}
 
+#if __GLASGOW_HASKELL__ >= 806
+{-# LANGUAGE NoStarIsType #-}
+#endif
+
 -- | Natural numbers.
 --
 -- Note that the operators from this module conflict with "GHC.TypeLits" and
